==> ejc-jlprogress-impl-3.0.0-20240604.070703-142-sources.jar: com/ejianc/business/jlprogress/quality/bean/MatCheckDetailEntity.java <==
package com.ejianc.business.jlprogress.quality.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 质量检测-原材料检测记录子实体
 *
 * @author generator
 *
 */
 @TableName("ejc_quality_mat_check_detail")
public class MatCheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="check_id")
    private Long checkId; // 父id
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="spec")
    private String spec; // 规格
    @TableField(value="model")
    private String model; // 型号
    @TableField(value="texture")
    private String texture; // 材质
    @TableField(value="batch_number")
    private String batchNumber; // 炉批号
    @TableField(value="weight_num")
    private BigDecimal weightNum; // 重量
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="appea_result")
    private Integer appeaResult; // 外观：0-不合格1-合格
    @TableField(value="check_proj")
    private String checkProj; // 实测直径或厚度（mm)/检验项目
    @TableField(value="result_id")
    private Long resultId; // 结论ID
    @TableField(value="result_name")
    private String resultName; // 结论名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源ID
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型1-供货单2-物资档案


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }
    public String getTexture() {
        return texture;
    }

    public void setTexture(String texture) {
        this.texture = texture;
    }
    public String getBatchNumber() {
        return batchNumber;
    }

    public void setBatchNumber(String batchNumber) {
        this.batchNumber = batchNumber;
    }
    public BigDecimal getWeightNum() {
        return weightNum;
    }

    public void setWeightNum(BigDecimal weightNum) {
        this.weightNum = weightNum;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public Integer getAppeaResult() {
        return appeaResult;
    }

    public void setAppeaResult(Integer appeaResult) {
        this.appeaResult = appeaResult;
    }
    public String getCheckProj() {
        return checkProj;
    }

    public void setCheckProj(String checkProj) {
        this.checkProj = checkProj;
    }
    public Long getResultId() {
        return resultId;
    }

    public void setResultId(Long resultId) {
        this.resultId = resultId;
    }
    public String getResultName() {
        return resultName;
    }

    public void setResultName(String resultName) {
        this.resultName = resultName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
}

==> ejc-jlprogress-impl-3.0.0-20241127.095459-466-sources.jar: com/ejianc/business/jlprogress/quality/bean/MatCheckDetailEntity.java <==
package com.ejianc.business.jlprogress.quality.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 质量检测-原材料检测记录子实体
 *
 * @author generator
 *
 */
 @TableName("ejc_quality_mat_check_detail")
public class MatCheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="check_id")
    private Long checkId; // 父id
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="spec")
    private String spec; // 规格
    @TableField(value="model")
    private String model; // 型号
    @TableField(value="texture")
    private String texture; // 材质
    @TableField(value="batch_number")
    private String batchNumber; // 炉批号
    @TableField(value="weight_num")
    private BigDecimal weightNum; // 重量
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="appea_result")
    private Integer appeaResult; // 外观：0-不合格1-合格

    @TableField(value="size")
    private Integer size; // 尺寸：0-不合格1-合格
    @TableField(value="check_proj")
    private String checkProj; // 实测直径或厚度（mm)/检验项目
    @TableField(value="result_id")
    private Long resultId; // 结论ID
    @TableField(value="result_name")
    private String resultName; // 结论名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源ID
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型1-供货单2-物资档案


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }
    public String getTexture() {
        return texture;
    }

    public void setTexture(String texture) {
        this.texture = texture;
    }
    public String getBatchNumber() {
        return batchNumber;
    }

    public void setBatchNumber(String batchNumber) {
        this.batchNumber = batchNumber;
    }
    public BigDecimal getWeightNum() {
        return weightNum;
    }

    public void setWeightNum(BigDecimal weightNum) {
        this.weightNum = weightNum;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public Integer getAppeaResult() {
        return appeaResult;
    }

    public void setAppeaResult(Integer appeaResult) {
        this.appeaResult = appeaResult;
    }
    public String getCheckProj() {
        return checkProj;
    }

    public void setCheckProj(String checkProj) {
        this.checkProj = checkProj;
    }
    public Long getResultId() {
        return resultId;
    }

    public void setResultId(Long resultId) {
        this.resultId = resultId;
    }
    public String getResultName() {
        return resultName;
    }

    public void setResultName(String resultName) {
        this.resultName = resultName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }
}
